<?php
/**
 * DemonstrativoAlteracaoSalarial.
 *
 * @package Logic
 * @author  alessandrobartels
 *
 */
class DemonstrativoAlteracaoSalarial {

    private $_tipoAlteracao;
    private $_mesCompetencia;
    private $_registros = array();


    /**
     * Construtor.
     *
     * @param string $tipo_alteracao  Descricao do Tipo de Alteracao Salarial.
     * @param string $mes_competencia Mes de Competencia.
     *
     * @author alessandrobartels
     */
    public function __construct($tipo_alteracao, $mes_competencia){
        $this->_tipoAlteracao = $tipo_alteracao;
        $this->_mesCompetencia = $mes_competencia;
    }


    /**
     * Adiciona registros ao Demonstrativo.
     *
     * @param string $dsVinculo          Descricao do vinculo.
     * @param float  $salario_anterior   Salario sem reajuste.
     * @param float  $salario_reajustado Salario reajustado.
     * @param float  $percentual_real    Percentual real de reajuste.
     * @param float  $vr_diferenca_real  Valor da diferenca entre o salario reajustado e o sem reajuste.
     *
     * @return Registro
     *
     * @author alessandrobartels
     */
    public function addRegistros(
        $dsVinculo, $salario_anterior, $salario_reajustado, $percentual_real, $vr_diferenca_real
    ){
        /* TkDebug::var_dump($percentual_real); */
        $registro = new Registro(
            $dsVinculo, $salario_anterior, $salario_reajustado, $percentual_real, $vr_diferenca_real
        );
        $this->_registros[] = $registro;
        return $registro;
    }


    /**
     * Metodo __toString.
     *
     * @return string
     *
     * @author alessandrobartels
     */
    public function __toString(){

        /* Ordena o vetor de objetos conforme funcao comparaOrdemEventos()*/
        /* usort($this->_eventos, array('Demonstrativo', 'comparaOrdemImpressao')); */

        $i = 1;
        foreach ($this->_registros as $registro) {
            if ($i === 1) {
                $saida = 'Tipo de Alteracao: '.$this->_tipoAlteracao.'<br/>';
                $saida .= 'Data: '.$this->_mesCompetencia.'<br/>';
                $saida .= '
							<table class = "resultado">
								<tr>
								   	<th>Vinculo</th>
								   	<th>Salario Anterior</th>
									<th>Salario Reajustado</th>
									<th>Diferenca Real</th>
									<th>Percentual Real</th>
								</tr> ';
            }

            $saida .= $registro;
            $i++;
        }

        if ($i > 1) {
            $saida .= '</table><br/>';
        }

        return $saida;
    }


}


/**
 * Registro.
 *
 * @package Logic
 * @author  alessandrobartels
 *
 */
class Registro {

    private $_vinculo;
    private $_salarioAnterior;
    private $_salarioReajustado;
    private $_diferencaReal;
    private $_percentualReal;


    /**
     * Construtor.
     *
     * @param string $dsVinculo          Descricao do vinculo.
     * @param float  $salario_anterior   Salario sem reajuste.
     * @param float  $salario_reajustado Salario reajustado.
     * @param float  $percentual_real    Percentual real de reajuste.
     * @param float  $diferenca_real     Valor da diferenca entre o salario reajustado e o sem reajuste.
     *
     * @author alessandrobartels
     */
    public function __construct(
        $dsVinculo, $salario_anterior, $salario_reajustado, $percentual_real, $diferenca_real
    ){
        $this->_vinculo = $dsVinculo;
        $this->_salarioAnterior = $salario_anterior;
        $this->_salarioReajustado = $salario_reajustado;
        $this->_diferencaReal = $diferenca_real;
        $this->_percentualReal = $percentual_real;
    }


    /**
     * Metodo __toString.
     *
     * @return string
     *
     * @author alessandrobartels
     */
    public function __toString(){
        $saida = '<tr>
						<td align="left">'.$this->_vinculo.'</td>
						<td align="right">'.number_format($this->_salarioAnterior, 2, ', ', '. ').'</td>
						<td align="right">'.number_format($this->_salarioReajustado, 2, ', ', '. ').'</td>
						<td align="right">'.number_format($this->_diferencaReal, 2, ', ', '. ').'</td>
						<td align="right">'.$this->_percentualReal/*number_format($this->_percentualReal, 2, ', ', '. ')*/.'</td>
				 </tr>';
        return $saida;
    }


}